@@ -1,23 +1,23 @@
 package PNI::Node::Tk::Canvas;
+use parent 'PNI::Node';
 use strict;
-use warnings;
-use base 'PNI::Node';
-
-my $default_configure_opts = { -height => 200, -width => 300 } ;
 
 sub init {
     my $node = shift;
 
     my $parent = $node->add_input('parent');
 
-    my $configure_opts = $node->add_input('configure_opts');
+    my $configure_opts = $node->add_input(
+        'configure_opts' => {
+            -height => 200,
+            -width  => 300,
+        }
+    );
 
     my $pack_opts = $node->add_input('pack_opts');
 
     my $canvas = $node->add_output('canvas');
 
-    $configure_opts->set_data( $default_configure_opts );
-
     return 1;
 }
 
@@ -37,25 +37,31 @@ sub task {
 
     return 1 if $parent->is_undef;
 
-    if ( $canvas->is_undef ) { }
-    else {
+    if ( $canvas->is_undef ) {
 
-        #my $tk_main_window = $parent->get_output('main_window')->get_data;
-        my $tk_main_window = $parent->data;
+        my $tk_main_window = $parent->get_data;
 
         my $tk_canvas = $tk_main_window->Canvas;
         $canvas->set_data($tk_canvas);
 
-        $tk_canvas->configure( %{ $configure_opts->get_data } );
+        #$tk_canvas->configure( $configure_opts->get_data );
+        $tk_canvas->configure( 
+            -confine => 0,
+            -height => 400, 
+            -width => 600,
+            -scrollregion => [0,0,1000,1000],
+            -background => 'white' 
+        );
 
-        $tk_canvas->pack( %{ $pack_opts->get_data } );
-        print $tk_canvas;
+        #$tk_canvas->pack( %{ $pack_opts->get_data } );
+        $tk_canvas->pack( -expand => 1 , -fill => 'both' );
     }
 
     return 1;
 }
 
 1;
+__END__
 
 =head1 NAME
 
